@@ -121,6 +121,8 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
         # self.btn_g2_export.clicked.connect(self.export_g2)
         # disable browse function; it freezes on linux workstation;
         # self.pushButton.setEnabled(False)
+        self.btn_up.clicked.connect(lambda: self.reorder_target('up'))
+        self.btn_down.clicked.connect(lambda: self.reorder_target('down'))
 
         self.update_g2_fitting_function()
         self.show()
@@ -705,7 +707,14 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
         self.vk.export_g2()
 
     def reload_source(self):
-        self.vk.build()
+        self.pushButton_11.setText('loading')
+        self.pushButton_11.setDisabled(True)
+        self.pushButton_11.parent().repaint()
+        self.vk.build(sort_method=self.sort_method.currentText())
+        self.pushButton_11.setText('reload')
+        self.pushButton_11.setEnabled(True)
+        self.pushButton_11.parent().repaint()
+
         self.update_box(self.vk.source, mode='source')
         self.trie_search()
 
@@ -731,7 +740,10 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
             self.plot_state[:] = 0
 
         self.work_dir.setText(f)
+
         self.vk = ViewerKernel(f, self.statusbar)
+        self.reload_source()
+
         self.avg_job_table.setModel(self.vk.avg_worker)
         # self.thread = QThread()
         # self.vk.moveToThread(self.thread)
@@ -744,6 +756,7 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
         if mode == 'source':
             self.list_view_source.setModel(file_list)
             self.box_source.setTitle('Source: %5d' % len(file_list))
+            self.box_source.parent().repaint()
         elif mode == 'target':
             self.list_view_target.setModel(file_list)
             self.box_target.setTitle('Target: %5d \t [Type: %s] ' %
@@ -816,19 +829,27 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
             else:
                 self.load_data()
 
-    def reorder_target(self):
-        target = []
-        self.list_view_target.selectAll()
-        for x in self.list_view_target.selectedIndexes():
-            target.append(x.data())
-        self.list_view_target.clearSelection()
+    def reorder_target(self, direction='up'):
+        rows = self.get_selected_rows()
+        if len(rows) != 1 or len(self.vk.target) <= 1:
+            return
+        row = rows[0]
 
-        if tuple(target) != tuple(self.vk.target):
-            self.vk.clear_target()
-            self.vk.add_target(target)
-            self.update_box(self.vk.target, mode='target')
-        else:
-            print('no reorder')
+        if direction == 'up' and row == 0:
+            self.statusbar.showMessage('alread on the top', 1000)
+            return
+        elif direction == 'down' and row == len(self.vk.target) - 1:
+            self.statusbar.showMessage('alread on the buttom', 1000)
+            return
+
+        item = self.vk.target.pop(row)
+        pos = row - 1 if direction == 'up' else row + 1
+        self.vk.target.insert(pos, item)
+        idx = self.vk.target.index(pos)
+        self.list_view_target.setCurrentIndex(idx)
+        self.list_view_target.repaint()
+
+        return
 
     def remove_target(self):
         if self.data_state in [0, 1]:
