@@ -84,7 +84,8 @@ class ViewerKernel(FileLocator):
     def plot_g2(self, handler, q_range, t_range, y_range, max_points=128,
                 rows=None, **kwargs):
         xf_list = self.get_xf_list(max_points, rows=rows) 
-        g2mod.pg_plot(handler, xf_list, q_range, t_range, y_range, **kwargs)
+        g2mod.pg_plot(handler, xf_list, q_range, t_range, y_range, rows=rows,
+                      **kwargs)
         return
 
     def plot_tauq_pre(self, hdl=None, max_points=128, rows=None):
@@ -117,8 +118,7 @@ class ViewerKernel(FileLocator):
 
     def plot_saxs_1d(self, mp_hdl, max_points=128, **kwargs):
         xf_list = self.get_xf_list(max_points)
-        saxs1d.plot(xf_list, mp_hdl, max_points=max_points, 
-                    legend=self.id_list, **kwargs)
+        saxs1d.plot(xf_list, mp_hdl, max_points=max_points, **kwargs)
 
     def setup_twotime(self, file_index=0, group='xpcs'):
         fname = self.target[file_index]
